@@ -199,32 +199,32 @@ class ApiGatewayToKinesisStreams(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
@@ -275,15 +275,15 @@ class ApiGatewayToKinesisStreamsProps:
         :summary: The properties for the ApiGatewayToKinesisStreamsProps class.
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
+            api_gateway_props = RestApiProps(**api_gateway_props)
         if isinstance(kinesis_stream_props, dict):
-            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
+            kinesis_stream_props = StreamProps(**kinesis_stream_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = LogGroupProps(**log_group_props)
         if isinstance(put_record_request_model, dict):
-            put_record_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_record_request_model)
+            put_record_request_model = ModelOptions(**put_record_request_model)
         if isinstance(put_records_request_model, dict):
-            put_records_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_records_request_model)
+            put_records_request_model = ModelOptions(**put_records_request_model)
         if __debug__:
             type_hints = typing.get_type_hints(ApiGatewayToKinesisStreamsProps.__init__)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
